Stan Math Library: stan/math/prim/mat/fun/fill.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

fill.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_FILL_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_FILL_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5
6 namespace stan {
7 namespace math {
8
21 template <typename T, int R, int C, typename S>
22 void fill(Eigen::Matrix<T, R, C>& x, const S& y) {
23 x.fill(y);
24 }
25
26 }
27 }
28 #endif
stan
Definition: log_sum_exp.hpp:8
Eigen.hpp
stan::math::fill
void fill(std::vector< T > &x, const S &y)
Fill the specified container with the specified value.
Definition: fill.hpp:22

[ Stan Home Page ] © 2011–2016, Stan Development Team.